@@ -25,7 +25,7 @@ export class CLASS_NAMEHubPredictor implements IMLAsyncPredictor<object> {
      * @param features Input features.
      * @returns Prediction output.
      */
-    public async predict (...features: MLFeature[]): Promise<object> {
+    public async predict (...features: MLFeature[]) {
         /**
          * __Check inputs__
          * Check that the correct number of inputs is passed in.
